@@ -1,7 +1,7 @@
 package Time::HiRes;
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
+use vars qw($VERSION @ISA @EXPORT @EXPORT_OK @EXPORT_FAIL);
 
 require Exporter;
 require DynaLoader;
@@ -9,26 +9,29 @@ require DynaLoader;
 @ISA = qw(Exporter DynaLoader);
 
 @EXPORT = qw( );
-@EXPORT_OK = qw (time alarm sleep);
+@EXPORT_OK = qw (usleep sleep ualarm alarm gettimeofday time tv_interval);
 
-( $VERSION ) = '$Revision: 1.2 $ ' =~ /\$Revision\:\s+([^\s]+)/; $VERSION = join(".", map { $_ = sprintf ("%2.2d", $_) } split (/\./, $VERSION));
+$VERSION = do{my@r=q$Revision: 1.10 $=~/\d+/g;sprintf '%02d.'.'%02d'x$#r,@r};
 
 bootstrap Time::HiRes $VERSION;
 
+@EXPORT_FAIL = grep { ! defined &$_ } @EXPORT_OK;
+
 # Preloaded methods go here.
 
 sub tv_interval {
     # probably could have been done in C
     my ($a, $b) = @_;
-    $b = [&gettimeofday] unless defined($b);
+    $b = [gettimeofday()] unless defined($b);
     (${$b}[0] - ${$a}[0]) + ((${$b}[1] - ${$a}[1]) / 1_000_000);
 }
 
-sub alarm {
-    # definitely should have been done in C, but this is educational!
-    my ($seconds, $interval) = @_;
-    $interval = 0 unless defined($interval);
-    ualarm ($seconds*1_000_000, $interval*1_000_000);
+# I'm only supplying this because the version of it in 5.003's Export.pm
+# is buggy (it doesn't shift off the class name).
+
+sub export_fail {
+    my $self = shift;
+    @_;
 }
 
 # Autoload methods go after =cut, and are processed by the autosplit program.
@@ -42,41 +45,38 @@ Time::HiRes - Perl extension for ualarm, usleep, and gettimeofday
 
 =head1 SYNOPSIS
 
-  use Time::HiRes;
+  use Time::HiRes qw( usleep ualarm gettimeofday tv_interval );
 
-  Time::HiRes::usleep ($microseconds);
+  usleep ($microseconds);
 
-  Time::HiRes::ualarm ($microseconds, $interval_microseconds);
+  ualarm ($microseconds);
+  ualarm ($microseconds, $interval_microseconds);
 
-  $t0 = [Time::HiRes::gettimeofday];
-  ($seconds, $microseconds) = Time::HiRes::gettimeofday;
+  $t0 = [gettimeofday];
+  ($seconds, $microseconds) = gettimeofday;
 
-  $elapsed = Time::HiRes::tv_interval ( $t0, [$seconds, $microseconds]);
-  $elapsed = Time::HiRes::tv_interval ( $t0, [Time::HiRes::gettimeofday]);
-  $elapsed = Time::HiRes::tv_interval ( $t0 );
+  $elapsed = tv_interval ( $t0, [$seconds, $microseconds]);
+  $elapsed = tv_interval ( $t0, [gettimeofday]);
+  $elapsed = tv_interval ( $t0 );
 
-  $now_fractions = Time::HiRes::time;
-
-  Time::HiRes::sleep ($floating_seconds);
-
-  Time::HiRes::alarm ($floating_seconds);
-  Time::HiRes::alarm ($floating_seconds, $floating_interval);
- 
   use Time::HiRes qw ( time alarm sleep );
   $now_fractions = time;
   sleep ($floating_seconds);
   alarm ($floating_seconds);
+  alarm ($floating_seconds, $floating_interval);
 
 =head1 DESCRIPTION
 
-The C<Time::HiRes> package implements a Perl interface to usleep, ualarm,
+The C<Time::HiRes> package implements a Perl interface to the usleep, ualarm,
 and gettimeofday system calls. See the EXAMPLES section below and the test
 scripts for usage; see your system documentation for the description of
 the underlying gettimeofday, usleep, and ualarm calls.
 
-Note that if your system does not implement usleep(), ualarm(), and
-gettimeofday(), you will not be able to use this module. If you are in 
-this situation, see MISSING UALARM() AND FRIENDS below.
+If your system lacks gettimeofday() you don't get gettimeofday() or the
+one-arg form of tv_interval().  If you don't have usleep() or select()
+you don't get usleep() or sleep().  If you don't have ualarm() you don't
+get ualarm() or alarm().  If you try to import an unimplemented function
+in the C<use> statement it will fail at compile time.
 
 =item gettimeofday
 
@@ -84,7 +84,7 @@ Returns a 2 element array with the second and microseconds since the epoch.
 
 =item usleep ( $useconds )
 
-Issues a usleep for the # of microseconds specified. See also 
+Issues a usleep for the number of microseconds specified. See also 
 Time::HiRes::sleep.
 
 =item ualarm ( $useconds [, $interval_useconds ] )
@@ -100,14 +100,14 @@ current time is use.
 
 =item time 
 
-Returns a floating seconds since the epoch. This function can be exported,
+Returns a floating seconds since the epoch. This function can be imported,
 resulting in a nice drop-in replacement for the C<time> provided with perl,
 see the EXAMPLES below.
 
 =item sleep ( $floating_seconds )
 
 Converts $floating_seconds to microseconds and issues a usleep for the 
-result.  This function can be exported, resulting in a nice drop-in 
+result.  This function can be imported, resulting in a nice drop-in 
 replacement for the C<sleep> provided with perl, see the EXAMPLES below.
 
 =item alarm ( $floating_seconds [, $interval_floating_seconds ] )
@@ -115,32 +115,32 @@ replacement for the C<sleep> provided with perl, see the EXAMPLES below.
 Converts $floating_seconds and $interval_floating_seconds and issues a
 ualarm for the results.  $interval_floating_seconds is optional and will 
 be 0 if unspecified, resulting in alarm-like behaviour.  This function can 
-be exported, resulting in a nice drop-in 
+be imported, resulting in a nice drop-in 
 replacement for the C<alarm> provided with perl, see the EXAMPLES below.
 
 =head1 EXAMPLES
 
-  use Time::HiRes;
+  use Time::HiRes qw(usleep ualarm gettimeofday tv_interval);
 
   $microseconds = 750_000;
-  Time::HiRes::usleep ($microseconds);
+  usleep $microseconds;
 
-  # signal alarm in 2.5s & every .1 s thereafter
-  Time::HiRes::ualarm (2_500_000, 100_000);	
+  # signal alarm in 2.5s & every .1s thereafter
+  ualarm 2_500_000, 100_000;	
 
   # get seconds and microseconds since the epoch
-  ($s, $usec) = Time::HiRes::gettimeofday;
+  ($s, $usec) = gettimeofday;
 
   # measure elapsed time 
-  # (could also do by subtracting 2 Time::HiRes:gettimeofday_f return values)
-  $t0 = [Time::HiRes::gettimeofday];
+  # (could also do by subtracting 2 gettimeofday return values)
+  $t0 = [gettimeofday];
   # do bunch of stuff here
-  $t1 = [Time::HiRes::gettimeofday];
+  $t1 = [gettimeofday];
   # do more stuff here
-  $t0_t1 = Time::HiRes::tv_interval ($t0, $t1);
+  $t0_t1 = tv_interval $t0, $t1;
   
-  $elapsed = Time::HiRes::tv_interval ($t0, [Time::HiRes::gettimeofday]);
-  $elapsed = Time::HiRes::tv_interval ($t0);	# equivalent code
+  $elapsed = tv_interval ($t0, [gettimeofday]);
+  $elapsed = tv_interval ($t0);	# equivalent code
 
   #
   # replacements for time, alarm and sleep that know about floating seconds
@@ -155,15 +155,23 @@ replacement for the C<alarm> provided with perl, see the EXAMPLES below.
   sleep (2.5);
   alarm (10.6666666);
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 D. Wegscheid <wegscd@whirlpool.com>
+R. Schertler <roderick@argon.org>
+J. Hietaniemi <jhi@iki.fi>
 
 =head1 REVISION
 
-$Id: HiRes.pm,v 1.2 1996/12/30 13:28:40 wegscd Exp $
+$Id: HiRes.pm,v 1.10 1997/05/23 01:11:38 wegscd Exp $
 
 $Log: HiRes.pm,v $
+Revision 1.10  1997/05/23 01:11:38  wegscd
+Conditional compilation; EXPORT_FAIL fixes.
+
+Revision 1.10  1997/05/23 00:53:19  wegscd
+Add conditional compilation, fix EXPORT_FAIL, misc cleanup.
+
 Revision 1.2  1996/12/30 13:28:40  wegscd
 Update documentation for what to do when missing ualarm() and friends.
 
@@ -173,20 +181,6 @@ Fix =head1 being next to __END__ so pod2man works
 Revision 1.0  1996/09/03 18:25:15  wegscd
 Initial revision
 
-=head1 MISSING UALARM() AND FRIENDS
-
-If you have a system that does not have ualarm(), usleep(), and
-gettimeofday(), and you want to see this module work with it, you have
-two options: modify the source code to work with your system, or get me
-access to your system to do it (no promises about timeliness on this one!). 
-
-I have received mail from HP-UX, Linux, and Solaris users in this boat,
-and it's hard for me to tell if it's a simple problem of not having
-the correct libraries installed or if the routines are missing altogether.
-
-If you make changes, let me know so they can be integrated back into the 
-source so other users can benefit from your work. Thanks...
-
 =head1 COPYRIGHT
 
 Copyright (c) 1996 Douglas E. Wegscheid.
@@ -194,10 +188,3 @@ All rights reserved. This program is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
-
-sub ualarm
- {
-  my ($useconds, $uinterval) = @_;
-  $uinterval = 0 unless defined($uinterval);
-  ualarm ($useconds, $uinterval);
- }
